---
title: About the project
---

# About the project

**Here you can find our core documents.**

Requirements engineering:
- [Requirements Specification _(legacy)_](/tesi/project/requirements-specification)
- [Project Plan _(legacy)_](/tesi/project/project-plan)
- [Use Cases](/tesi/project/use-cases)

Process engineering:
- [Process Model](/tesi/project/process-model)
- [Continuous Integration](/tesi/project/continuous-integration)

Project philosophy:
- [Project Philosophy](/tesi/project/project-philosophy)
